/* _______________________________________________________________________
	TrinityTuner.h - Tuner module support constants for Trinity
	
	first created: 4/3/2001
	
	copyright  1999-2001 by David DeHaven - all rights reserved.
 _______________________________________________________________________*/

#ifndef _TrinityTuner_
#define _TrinityTuner_

	#include <Trinity/TrinityCommon.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
	This is a control channel, there is no data flow associated with it
*/

enum {
	kTRPipeTypeTuner = 'Tunr',
	
	/* These values are used internally, you should not need to work with them directly */
	/* Setting Selectors				   GET/SET	*/
	kTRTunerType = 'Ttyp',				/* GET     - Get the type of tuner connected */
	kTRTunerStatus = 'TSta',			/* GET     - Get the tuner status (see status bits below) */
	kTRTunerDemodStatus = 'TDst',		/* GET     - Get the tuner status from the IF demodulator (MK3 tuners) */
	
		/* the next two settings are superceeded by kTRTunerCodes */
	kTRTunerControlCode = 'Tcnt',		/*     SET - Send the given control code to the tuner */
	kTRTunerDividerCode = 'Tdiv',		/*     SET - Send the given divider code to the tuner */
	
	kTRTunerFrequency = 'Freq',			/* GET/SET - Desired tuner frequency */
	kTRTunerStandard = 'TStd',			/* GET/SET - Sets desired transmission standard */
	kTRTunerInput = 'TInp',				/* GET/SET - Selects which input is to be tuned next (for multi-input tuners) */
	kTRTunerTuningRatio = 'Trat',		/* GET/SET - Sets the tuning ratio (frequency step) */
	
		/* these are used when the tuner type is not supported, or marked "external" */
	kTRTunerInfo = 'Tinf',				/* GET     - Get tuner information */
	kTRTunerProtocol = 'Tprt',			/* GET     - Get tuning information for the given standard and input */
	
	kTRTunerCodes = 'Tcod'				/*     SET - Sends raw tuner codes to the tuner */
};
	
enum {
	/* Ratio select bit values */
	kTRTunerRatioSelect_31250 = 0x01,
	kTRTunerRatioSelect_50000 = 0x02,
	kTRTunerRatioSelect_62500 = 0x04,
	
	/* Ratio select divider values, choose frequencies in these steps */
	kTRTunerRatioDivider_31250 = 31250,
	kTRTunerRatioDivider_50000 = 50000,
	kTRTunerRatioDivider_62500 = 62500,
	
	/* Status code bits */
	kTRTunerStatusAFCStatusBits = 0x07,
	kTRTunerStatusPLLLockedBit = 0x40,
	kTRTunerStatusCarrierDetectBit = 0x80,	// does not match raw status code!
	
	/* AFC status bit meanings */
	kTRTunerAFCStatus_neg2 = 0x00,		// increase 125KHz or more
	kTRTunerAFCStatus_neg1 = 0x01,		// increase 62.5KHz
	kTRTunerAFCStatus_Tuned = 0x02,		// frequency is close enough
	kTRTunerAFCStatus_pos1 = 0x03,		// decrease 62.5KHz
	kTRTunerAFCStatus_pos2 = 0x04,		// decrease 125KHz or more
		// other values are undefined
	
	/* Transmissions standards supported by various tuners */
	kTRTunerStandard_NTSC = 0x0001,		/* both M and N */
	kTRTunerStandard_PAL_BG = 0x0002,
	kTRTunerStandard_PAL_I = 0x0004,
	kTRTunerStandard_PAL_DK = 0x0008,
	kTRTunerStandard_PAL_M = 0x0010,
	kTRTunerStandard_SECAM = 0x0020,		/* both L and L' */
	kTRTunerStandard_FM = 0x0040,
	kTRTunerStandard_ATSCDigital = 0x0080		/* all currently supported digital formats */
};

enum {
		/* Tuner channel errors */
	kTRTunerUnknownTunerTypeErr = 3000,	/* the hardware driver has specified a tuner type that is not supported currently */
	kTRTunerInvalidTunerStandardErr,
	kTRTunerInvalidTunerInputErr,
	kTRTunerInvalidTuningRatioErr,
	kTRTunerFrequencyOutOfRangeErr,
	kTRTunerFrequencyNotSet		/* the driver stored the value, but hardware was not set (not necessarily an error) */
};

/* macros to help determine if a general (QT-like) standard is supported */
	// NTSC tuners are used for both NTSC and PAL-M
#define TRTUNER_DOES_NTSC(s) (((s) & kTRTunerStandard_NTSC)||((s) & kTRTunerStandard_PAL_M))
#define TRTUNER_DOES_PAL(s) (((s) & kTRTunerStandard_PAL_BG)||((s) & kTRTunerStandard_PAL_I)||((s) & kTRTunerStandard_PAL_DK))
#define TRTUNER_DOES_SECAM(s) ((s) & kTRTunerStandard_SECAM)
#define TRTUNER_DOES_FM(s) ((s) & kTRTunerStandard_FM)

#ifdef __cplusplus
}
#endif

#endif /* _TrinityTuner_ */

/*______________________________________________________________________*/
